<?php
// SPDX-License-Identifier: EUPL-1.2
// Authors: see README.md

namespace PicoContentEditor\EditorsHandlers;

class ContentTools
{
    /**
     * Return the HTML links and scripts tags needed by the editor,
     * that will be included with {{ content_editor }}
     *
     * @param \PicoContentEditor $contentEditor
     * @param string $assetsUrl The URL to the plugin assets directory.
     * @return string
     */
    public static function assets($contentEditor, $assetsUrl)
    {
        $libUrlJs = rtrim("$assetsUrl/js/vendor/ContentTools");
        $lang = $contentEditor->getPluginSetting('Language');
        // TODO do not copy lang but use async script
        $langData = self::getLanguageContent($lang, $libUrlJs);
        return ['lang'=>$lang,'data'=>!empty($langData) ? $langData : ''];
    }
    
    /**
     * Return a ContentTools translation.
     *
     * @param string $lang The language code.
     * @return string The JSON data.
     */
    private static function getLanguageContent($lang, $libUrl)
    {
        if (!$lang) {
            return;
        }
        $path = "$libUrl/translations/$lang.json";
        return file_get_contents($path);
    }

    /**
     * process the edit input and return the content that will replace the existing one.
     *
     * @param object $edit The edit data object.
     * @return string
     */
    public static function getOutput($edit, $markdown)
    {
        if ($markdown) {
            $converter = new \Markdownify\Converter;
            return $converter->parseString($edit->html);
        }
        return $edit->html;
    }
}
